stringutils

package
v0.0.7-3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 24, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Contains

func Contains(str string, match string) bool

Does string contain match and is match not escaped

func IsEnclosedBy

func IsEnclosedBy(str string, charA, charB string) bool

Is string enclosed by unescaped `char`

func IsEscaped

func IsEscaped(str string, char string) bool

Is string completly escaped with `\`

func NeedsEscapeForRegex

func NeedsEscapeForRegex(char rune) bool

Does `char` need escaping for regex

func ToArray

func ToArray(sliceStr string) []string

Helper method for converting comma-separated string into string slices

func ToType

func ToType(str string) any

String to type conversion, converts typed strings into respective type

Types

This section is empty.

Jump to