package
Version:
v0.0.10-5
Opens a new window with list of versions in this module.
Published: Jan 3, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Does string contain match and is match not escaped
Is string enclosed by unescaped `char`
Is string completly escaped with `\`
func NeedsEscapeForRegex(char rune) bool
Does `char` need escaping for regex
Helper method for converting comma-separated string into string slices
String to type conversion, converts typed strings into respective type
Source Files
¶
Click to show internal directories.
Click to hide internal directories.